@@ -40,6 +40,8 @@ struct _OpenConnectGUI
 
 	GPid pid;
 	GIOChannel *channel;
+	GIOChannel *echannel;
+	GIOChannel *ichannel;
 
 	gchar *currentProfile;
 	GKeyFile *keyfile;
@@ -50,3 +52,5 @@ struct _OpenConnectGUI
 };
 
 #endif
+
+/* vim: set ts=4: */
